Internal API of PhysFields
==========================

.. py:property:: snek5000.output.phys_fields.PhysFields._reader

A reader class is initialized as a cached-property
:any:`sim.output.phys_fields._reader
<snek5000.output.phys_fields.PhysFields._reader>` and provides all the methods
for the public API of PhysFields. Various reader classes are defined in the
following sub-package:

.. autosummary::
   :toctree: ../_generated/

   snek5000.output.readers
